@@ -1,4 +1,4 @@
-# $Id: Currency.pm 1365 2006-08-10 14:47:20Z claco $
+# $Id: Currency.pm 1417 2006-09-16 02:19:18Z claco $
 package Handel::Currency;
 use strict;
 use warnings;
@@ -10,44 +10,58 @@ BEGIN {
     use Handel::Constraints qw/:all/;
     use Handel::Exception;
     use Handel::L10N qw/translate/;
+    use Locale::Currency;
+    use Locale::Currency::Format;
+    use Class::Inspector;
     use Carp;
 
-    __PACKAGE__->mk_group_accessors('simple', qw/converter value/);
+    __PACKAGE__->mk_group_accessors('simple', qw/converter value _code _format/);
+    __PACKAGE__->mk_group_accessors('component_class', qw/converter_class/);
 };
 
+__PACKAGE__->converter_class('Finance::Currency::Convert::WebserviceX');
+
 sub new {
-    my ($class, $value) = @_;
-    my $self = bless {
-        value => $value || 0
+    my ($class, $value, $code, $format) = @_;
+    my $self   = bless {
+        converter => $class->converter_class->new,
+        value     => $value || 0,
+        _format   => $format
     }, ref($class) || $class;
 
-    eval 'use Finance::Currency::Convert::WebserviceX';
-    if (!$@) {
-        $self->converter(
-            Finance::Currency::Convert::WebserviceX->new
-        );
+    if ($code) {
+        $self->code($code);
     };
 
     return $self;
 };
 
-sub format {
-    my ($self, $code, $format) = @_;
+sub code {
+    my $self = shift;
 
-    eval 'use Locale::Currency::Format';
-    if ($@) {
-        carp 'Currency formatting unavailable: Locale::Currency::Format not installed';
-        return $self->value;
+    if (scalar @_) {
+        my $code = shift;
+
+        throw Handel::Exception::Argument(
+            -details => translate('Currency code [_1] is invalid or malformed', $code)
+        ) unless constraint_currency_code($code) ||  !$code; ## no critic
+
+        $self->_code($code);
     };
 
+    return $self->_code;
+};
+
+sub format {
+    my ($self, $code, $format) = @_;
     my $cfg = Handel->config;
 
-    eval '$format = ' .  ($format || $cfg->{'HandelCurrencyFormat'});
-    $code ||= $cfg->{'HandelCurrencyCode'};
+    eval '$format = ' .  ($format || $self->_format || $cfg->{'HandelCurrencyFormat'}); ## no critic
+    $code ||= $self->code || $cfg->{'HandelCurrencyCode'};
 
     throw Handel::Exception::Argument(
-        -details => translate("Currency code '[_1]' is invalid or malformed", $code) . '.') unless
-            constraint_currency_code($code);
+        -details => translate('Currency code [_1] is invalid or malformed', $code)
+    ) unless constraint_currency_code($code); ## no critic
 
     return _to_utf8(currency_format($code, $self->value, $format));
 };
@@ -56,27 +70,22 @@ sub convert {
     my ($self, $from, $to, $format, $options) = @_;
     my $cfg = Handel->config;
 
-    if (!$self->converter) {
-        carp 'Currency conversion unavailable: Finance::Currency::Convert::WebserviceX not installed';
-        return;
-    };
-
-    $from ||= $cfg->{'HandelCurrencyCode'};
-    $to   ||= $cfg->{'HandelCurrencyCode'};
-    eval '$options = ' .  ($options || $cfg->{'HandelCurrencyFormat'});
+    $from ||= $self->code || $cfg->{'HandelCurrencyCode'};
+    $to   ||= $self->code || $cfg->{'HandelCurrencyCode'};
+    eval '$options = ' .  ($options || $self->_format || $cfg->{'HandelCurrencyFormat'}); ## no critic
 
     return if uc($from) eq uc($to);
 
     throw Handel::Exception::Argument(
-        -details => translate("Currency code '[_1]' is invalid or malformed", $from) . '.') unless
-            constraint_currency_code($from);
+        -details => translate('Currency code [_1] is invalid or malformed', $from)
+    ) unless constraint_currency_code($from); ## no critic
 
     throw Handel::Exception::Argument(
-        -details => translate("Currency code '[_1]' is invalid or malformed", $to) . '.') unless
-            constraint_currency_code($to);
+        -details => translate('Currency code [_1] is invalid or malformed', $to)
+    ) unless constraint_currency_code($to); ## no critic
 
     my $result = $self->new(
-        $self->converter->convert($self->value, $from, $to)
+        $self->converter->convert($self->value, $from, $to), $self->code, $self->_format
     );
 
     if (defined $result && $format) {
@@ -86,6 +95,20 @@ sub convert {
     return $result;
 };
 
+sub name {
+    my ($self, $code) = @_;
+
+    if (!$code) {
+        $code = $self->code || Handel->config->{'HandelCurrencyCode'};
+    };
+
+    throw Handel::Exception::Argument(
+        -details => translate('Currency code [_1] is invalid or malformed', $code)
+    ) unless constraint_currency_code($code); ## no critic
+
+    return code2currency($code);
+};
+
 sub stringify {
     my $self = shift;
 
@@ -95,7 +118,7 @@ sub stringify {
 sub _to_utf8 {
     my $value = shift;
 
-    if ($] >= 5.008) {
+    if ($] >= 5.008) { ## no critic
         require utf8;
         utf8::upgrade($value);
     };
@@ -103,6 +126,30 @@ sub _to_utf8 {
     return $value;
 };
 
+sub get_component_class {
+    my ($self, $field) = @_;
+
+    return $self->get_inherited($field);
+};
+
+sub set_component_class {
+    my ($self, $field, $value) = @_;
+
+    if ($value) {
+        if (!Class::Inspector->loaded($value)) {
+            eval "use $value"; ## no critic
+
+            throw Handel::Exception(
+                -details => translate('The [_1] [_2] could not be loaded', $field, $value)
+            ) if $@; ## no critic
+        };
+    };
+
+    $self->set_inherited($field, $value);
+
+    return;
+};
+
 1;
 __END__
 
@@ -149,7 +196,7 @@ based price.
 
 =over
 
-=item Arguments: $price
+=item Arguments: $price [, $code, $formatoptions]
 
 =back
 
@@ -158,36 +205,70 @@ price to be formatted:
 
     my $currency = Handel::Currency->new(10.23);
 
+You can also pass in the default currency code and/or currency format to be used.
+
 =head1 METHODS
 
+=head2 code
+
+=over
+
+=item Arguments: $code
+
+=back
+
+Gets/sets the three letter currency code for the current currency object.
+
+C<code> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
+if C<code> isn't a valid currency code.
+
 =head2 convert
 
 =over
 
-=item Arguments: $from, $to [, $format, $options]
+=item Arguments: $from, $to [, $format, $formatoptions]
 
 =back
 
-The C<convert> method converts the given price from one currency to another
-using L<Finance::Currency::Convert::WebserviceX|Finance::Currency::Convert::WebserviceX>
-and returns a new currency object with the converted value.
-
-In situations where Finance::Currency::Convert::WebserviceX isn't installed,
-C<convert> simply returns 0.
-
-If no C<from> is specified, C<HandelCurrencyCode> will be used instead.
+If no C<from> or C<formatoptions> is specified, the options passed to C<new>
+and then C<HandelCurrencyCode> and C<HandelCurrencyFormat>  will be used instead.
 
 C<convert> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
 if C<from> or C<to> aren't valid currency codes.
 
 If C<format> is true, the result of the conversion will also be formatted
-using the formatting options given or the default in C<HandelCurrencyFormat>.
+using the formatting options given or the default in C<new> and then
+C<HandelCurrencyFormat>.
 
 You can also simply chain the C<convert> call into a C<format> call.
 
     my $price = Handel::Currency->new(1.25);
     print $price->convert('USD', 'CAD')->format;
 
+=head2 converter_class
+
+=over
+
+=item Arguments: $converter_class
+
+=back
+
+Gets/sets the converter class to be used when converting currency numbers.
+
+    __PACKAGE__->currency_class('MyCurrencyConverter');
+
+The converter class can be any class that supports the following method
+signature:
+
+    sub convert {
+        my ($self, $price, $from, $to) = @_;
+
+        return $converted_price;
+    };
+
+A L<Handel::Exception|Handel::Exception> exception will be thrown if the
+specified class can not be loaded.
+
 =head2 format
 
 =over
@@ -198,18 +279,31 @@ You can also simply chain the C<convert> call into a C<format> call.
 
 Returns the freshly formatted price in a currency and format declared in
 L<Locale::Currency::Format|Locale::Currency::Format>. If no currency code or
-format are specified, the defaults values from C<Handel::ConfigReader> are
-used. Currently those defaults are C<USD> and C<FMT_STANDARD>.
+format are specified, the defaults values from C<new> and then
+C<Handel::ConfigReader> are used. Currently those defaults are C<USD> and
+C<FMT_STANDARD>.
 
 It is also acceptable to specify different default values.
 See L</"CONFIGURATION"> and C<Handel::ConfigReader> for further details.
 
-In situations where Locale::Currency::Format isn't installed, C<format>
-simply returns the price in its original format no harm no foul.
-
 C<format> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
 if C<code> isn't a valid currency code.
 
+=head2 name
+
+=over
+
+=item Arguments $code
+
+=back
+
+Returns the currency name for the specified currency code. If no currency code
+is specified, the currency code for the current object will be used. If that
+too is not specified, the code set in C<HandelCurrencyCode> will be used.
+
+C<name> throws a L<Handel::Exception::Argument|Handel::Exception::Argument>
+if C<code> isn't a valid currency code.
+
 =head2 stringify
 
 Returns C<value> in scalar context. For now, this returns the same thing that
@@ -238,7 +332,8 @@ Locale::Currency::Format, you can combine options using C<|>.
 
 =head1 SEE ALSO
 
-L<Locale::Currency::Format>, L<Finance::Currency::Convert::WebserviceX>
+L<Locale::Currency>, L<Locale::Currency::Format>,
+L<Finance::Currency::Convert::WebserviceX>
 
 =head1 AUTHOR
 
